# Summary

## Getting Started
* [Introduction](README.md)
* [Installation](user-guide/installation.md)
* [Quick Start Guide](quick-start.md)

## Command Reference
* [Overview](user-guide/command-reference/index.md)
* [Search Command](user-guide/command-reference/search.md)
* [Enumerate Command](user-guide/command-reference/enumerate.md)
* [Attack Command](user-guide/command-reference/attack.md)

## Use Cases
* [Overview](user-guide/use-cases/index.md)
* [Scanning for Vulnerabilities](user-guide/use-cases/scanning.md)
* [Self-Hosted Runner Takeover](user-guide/use-cases/runner-takeover.md)
* [Post-Compromise Enumeration](user-guide/use-cases/post-compromise.md)

## Advanced Topics
* [Overview](user-guide/advanced/index.md)
* [Understanding GitHub Actions Vulnerabilities](user-guide/advanced/vulnerabilities.md)
* [Complex Attack Scenarios](user-guide/advanced/complex-attacks.md)

## Additional Resources
* [Contributing](contribution-guide/contributions.md)
